@@ -136,6 +136,8 @@ typedef enum {
 - (NSDictionary *)select:(NSString *)_folder;
 - (NSDictionary *)unselect;
 - (NSDictionary *)status:(NSString *)_folder flags:(NSArray *)_flags;
+- (NSDictionary *)annotation:(NSString *)_folder entryName:(NSString *)_entry attributeName:(NSString *)_attribute;
+- (NSDictionary *)annotation:(NSString *)_folder entryName:(NSString *)_entry attributeName:(NSString *)_attribute  attributeValue:(NSString *)_value;
 - (NSDictionary *)rename:(NSString *)_folder to:(NSString *)_newName;
 - (NSDictionary *)delete:(NSString *)_folder;
 - (NSDictionary *)create:(NSString *)_name;
@@ -147,6 +149,7 @@ typedef enum {
   encoding:(NSString *)_encoding;
 - (NSDictionary *)fetchUids:(NSArray *)_uids parts:(NSArray *)_parts;
 - (NSDictionary *)fetchUid:(unsigned)_uid    parts:(NSArray *)_parts;
+- (NSDictionary *) fetchModseqForUid: (unsigned)_uid;
 - (NSDictionary *)fetchVanished:(uint64_t)_modseq;
 - (NSDictionary *)fetchFrom:(unsigned)_from to:(unsigned)_to
   parts:(NSArray *)_parts;
