@@ -264,6 +264,12 @@ static int      LogImapEnabled = -1;
     if ([obj isKindOfClass:DictClass]) {
       if ((o = [obj  objectForKey:@"unseen"]))
         [result setObject:o forKey:@"unseen"];
+      else if ((o = [obj objectForKey:@"HIGHESTMODSEQ"]))
+        [result setObject:o forKey:@"highestmodseq"];
+      else if ((o = [obj objectForKey:@"UIDNEXT"]))
+        [result setObject:o forKey:@"uidnext"];
+      else if ((o = [obj objectForKey:@"UIDVALIDITY"]))
+        [result setObject:o forKey:@"uidvalidity"];
     }
     else
       [self warnWithFormat:@"unexpected OK object: %@", obj];
@@ -289,6 +295,7 @@ static int      LogImapEnabled = -1;
   return result;
 }
 
+
 - (NSDictionary *)normalizeStatusResponse:(NGHashMap *)_map {
   /*
     filter for status response
@@ -314,6 +321,10 @@ static int      LogImapEnabled = -1;
   }
   if ((o = [obj  objectForKey:@"unseen"]) != nil)
     [result setObject:o forKey:@"unseen"];
+
+  // support x-guid (dovecot)
+  if ((o = [obj  objectForKey:@"x-guid"]) != nil)
+    [result setObject:o forKey:@"x-guid"];
   
   return result;
 }
